#include <signal.h>
#include "contiki.h"
#include "net/rime.h"
#include "dev/leds.h"
#include <stdio.h>
#include <stdlib.h>

void motor_input(char*, int);

/////////////////

static void recv(struct abc_conn *c)
{
  char* data = packetbuf_dataptr();
  int len = packetbuf_datalen();
  leds_toggle(LEDS_RED);
  if(data[0] == 'm' && data[1] == 'o' && data[len-1] == '%'){
    leds_toggle(LEDS_GREEN);
    motor_input(data,len);
  }
  
}
static struct abc_callbacks abc_call = {recv};
static struct abc_conn abc;

////////////////////

interrupt (TIMERB1_VECTOR) TimerB(void)
{
  switch(TBIV){
    case 0x02:
      P6OUT &= ~(0x01);                          // 6.0 to 1
      break;
    case 0x0E: 
      P6OUT |= 0x01;			// 6.0 to 0
      break;
  }
}

void TimerBSetup(){
  TBCCTL0 = CCIE;                           // TBCCR0 interrupt enabled
  TBCCTL1 = CCIE;
  TBCCR0 = 38710;
  TBCCR1 = 2000;
  TBCTL = TBSSEL_2 +ID_1 + MC_1 + TBIE;                  // SMCLK, upmode
}

void PortSetup(){
  P6DIR |= 0x01; // 6.0 to output
}


PROCESS(mocontrol_process, "Motor Control");
AUTOSTART_PROCESSES(&mocontrol_process);
  
PROCESS_THREAD(mocontrol_process, ev, data)
{
  PROCESS_BEGIN();
  
  PortSetup();
  TimerBSetup();
  
  abc_open(&abc, 11, &abc_call);
  
  
  while(1) {
    PROCESS_YIELD();
  }
  PROCESS_END();
}


void motor_input(char* data, int len){
  int i, val = 0;
  leds_toggle(LEDS_BLUE);
 
  if(data[0] == 'm' && data[1] == 'o' && data[len-1] == '%'){
    for(i = 2; i < len-1; i++){
      val = val*10 + (int)(data[i] - '0');
    }
    //printf("Throttle: %d \n",val);
  }
  
  if(val < 0) val = 0;
  if(val > 100) val = 100;
  
  val *= 195;
  val /= 10;
  val += 1950;
  //printf("Counts: %d \n",val);
  TBCCR1 = val;
  
}


